..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``usage``
==================================================

`Leer en español </es/latest/reference/usage.html>`_

- **get usage**

Show resource usage and some statistics, like bandwidth, number of subdomains,
disk usage, number of mail filters, etc.

*Example*

.. code:: sh

    $ cpanel get usage

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/get_usages/


